==> 1.2.2.tar.gz: halcyon/widgets/side_dev_team.php <==
<div class="side_widget what_to_follow">
<h2>Interesting accounts of devs</h2>
<ul class="account_list">
<li class="account_box">
<div class="icon_box">
<img src="https://social.csswg.org/system/accounts/avatars/000/005/666/original/e9a158381ce1249a.png">
</div>
<div class="label_box">
<a href="/@halcyon@social.csswg.org">
<h3>
<span class="dn">Halcyon for Mastodon</span>
<span class="un">@halcyon@social.csswg.org</span>
</h3>
</a>
<button class="follow_button action_button" data="@halcyon@social.csswg.org">
<i class="fa fa-fw fa-user-plus"></i>
<span>Follow</span>
</button>
</div>
</li>
<li class="account_box">
<div class="icon_box">
<img src="https://social.wiuwiu.de/system/accounts/avatars/000/002/316/original/7cfc8223fe709e79.jpg">
</div>
<div class="label_box">
<a href="/@nipos@social.wiuwiu.de">
<h3>
<span class="dn">Niklas Poslovski</span>
<span class="un">@nipos@social.wiuwiu.de</span>
</h3>
</a>
<button class="follow_button" data="@nipos@social.wiuwiu.de">
<i class="fa fa-fw fa-user-plus"></i>
<span>Follow</span>
</button>
</div>
</li>
<li class="account_box">
<div class="icon_box">
<img src="https://files.mastodon.social/accounts/avatars/000/013/179/original/27bc451c7713091b.jpg">
</div>
<div class="label_box">
<a href="@Mastodon@mastodon.social">
<h3>
<span class="dn">Mastodon</span>
<span class="un">@Mastodon@mastodon.social</span>
</h3>
</a>
<button class="follow_button" data="@Mastodon@mastodon.social">
<i class="fa fa-fw fa-user-plus"></i>
<span>Follow</span>
</button>
</div>
</li>
<li class="account_box">
<div class="icon_box">
<img src="https://files.mastodon.social/accounts/avatars/000/000/001/original/4df197532c6b768c.png">
</div>
<div class="label_box">
<a href="@Gargron@mastodon.social">
<h3>
<span class="dn">Eugen</span>
<span class="un">@Gargron@mastodon.social</span>
</h3>
</a>
<button class="follow_button" data="@Gargron@mastodon.social">
<i class="fa fa-fw fa-user-plus"></i>
<span>Follow</span>
</button>
</div>
</li>
</ul>
</div>

==> 2.4.9.tar.gz: halcyon/widgets/side_dev_team.php <==
<div class="side_widget what_to_follow">
<h2><?=_('Interesting accounts of devs')?></h2>
<ul class="account_list">
<li class="account_box">
<div class="icon_box">
<img src="https://social.csswg.org/system/accounts/avatars/000/005/666/original/e9a158381ce1249a.png">
</div>
<div class="label_box">
<a href="/@halcyon@social.csswg.org">
<h3>
<span class="dn">Halcyon for Mastodon</span>
<span class="un">@halcyon@social.csswg.org</span>
</h3>
</a>
<button class="follow_button action_button" data="@halcyon@social.csswg.org">
<i class="fa fa-fw fa-user-plus"></i>
<span><?=_('Follow')?></span>
</button>
</div>
</li>
<li class="account_box">
<div class="icon_box">
<img src="https://social.netzkombinat.su/media/78fe7b24-8083-420c-b51f-39b9a6d71097/76af8a2c8993843b80f330ede0200c7532d026b5e6bb4e4ec64f2a68e5418869.png">
</div>
<div class="label_box">
<a href="/@nipos@social.netzkombinat.su">
<h3>
<span class="dn">Niklas Poslovski</span>
<span class="un">@nipos@social.netzkombinat.su</span>
</h3>
</a>
<button class="follow_button" data="@nipos@social.netzkombinat.su">
<i class="fa fa-fw fa-user-plus"></i>
<span><?=_('Follow')?></span>
</button>
</div>
</li>
<li class="account_box">
<div class="icon_box">
<img src="https://files.mastodon.social/accounts/avatars/000/013/179/original/27bc451c7713091b.jpg">
</div>
<div class="label_box">
<a href="@Mastodon@mastodon.social">
<h3>
<span class="dn">Mastodon</span>
<span class="un">@Mastodon@mastodon.social</span>
</h3>
</a>
<button class="follow_button" data="@Mastodon@mastodon.social">
<i class="fa fa-fw fa-user-plus"></i>
<span><?=_('Follow')?></span>
</button>
</div>
</li>
<li class="account_box">
<div class="icon_box">
<img src="https://files.mastodon.social/accounts/avatars/000/000/001/original/4df197532c6b768c.png">
</div>
<div class="label_box">
<a href="@Gargron@mastodon.social">
<h3>
<span class="dn">Eugen</span>
<span class="un">@Gargron@mastodon.social</span>
</h3>
</a>
<button class="follow_button" data="@Gargron@mastodon.social">
<i class="fa fa-fw fa-user-plus"></i>
<span><?=_('Follow')?></span>
</button>
</div>
</li>
</ul>
</div>
